$(document).ready(function() {

// the basics
// ----------

var substringMatcher = function(strs) {
  return function findMatches(q, cb) {
    var matches, substringRegex;

    // an array that will be populated with substring matches
    matches = [];

    // regex used to determine if a string contains the substring `q`
    substrRegex = new RegExp(q, 'i');

    // iterate through the pool of strings and for any string that
    // contains the substring `q`, add it to the `matches` array
    $.each(strs, function(i, str) {
      if (substrRegex.test(str)) {
        // the typeahead jQuery plugin expects suggestions to a
        // JavaScript object, refer to typeahead docs for more info
        matches.push({ value: str });
      }
    });

    cb(matches);
  };
};

var states = ["PC Engines ALIX.2", "Buffalo WZR-HP-AG300H", "TP-LINK TL-WR703N v1", "TP-LINK TL-MR3020", "TP-LINK TL-WR741ND v1", "TP-LINK TL-WR741ND v2", "TP-LINK TL-WR741ND v4", "TP-LINK TL-WR841N/ND v7", "TP-LINK TL-WR841N/ND v8", "TP-LINK TL-WDR4300", "TP-LINK TL-WDR4900 v1", "TP-LINK TL-WR940N", "TP-LINK TL-WR941ND v4", "TP-LINK TL-WR1043ND", "Ubiquiti Nanostation2", "Ubiquiti Nanostation5", "Ubiquiti Bullet M", "Ubiquiti Nanostation M", "Targa WR-500-VoIP", "Speedport W500V", "Linksys WRT54G/GS/GL", "Buffalo WHR-HP-G54", "Dell TrueMobile 2300", "ASUS WL-500g Premium", "T-Mobile InternetBox", "4G Systems MTX-1 Board", "D-Link DIR-300-B1"];

$('#the-basics .typeahead').typeahead({
  hint: true,
  highlight: true,
  minLength: 1
},
{
  name: 'states',
  displayKey: 'value',
  source: substringMatcher(states)
});

// bloodhound
// ----------

// constructs the suggestion engine
var states = new Bloodhound({
  datumTokenizer: Bloodhound.tokenizers.obj.whitespace('value'),
  queryTokenizer: Bloodhound.tokenizers.whitespace,
  // `states` is an array of state names defined in "The Basics"
  local: $.map(states, function(state) { return { value: state }; })
});

// kicks off the loading/processing of `local` and `prefetch`
states.initialize();

$('#bloodhound .typeahead').typeahead({
  hint: true,
  highlight: true,
  minLength: 1
},
{
  name: 'states',
  displayKey: 'value',
  // `ttAdapter` wraps the suggestion engine in an adapter that
  // is compatible with the typeahead jQuery plugin
  source: states.ttAdapter()
});

$('#rtl-support .typeahead').typeahead({
  hint: false
},
{
  name: 'arabic-phrases',
  displayKey: 'word',
  source: arabicPhrases.ttAdapter()
});
});
